cm-tpm is a Python module for data imputation and is distributed under the MIT licence.

The project was started in 2025 by Hakim Agni under the supervision of Thomas Krak at Eindhoven University of Technology. It implements the data imputation method described in the paper [Continuous Mixtures of Tractable Probabilistic Models](https://arxiv.org/abs/2209.10584), by Alvaro Correia, Gennaro Gala, Erik Quaeghebeur, Cassio de Campos and Robert Peharz.
